pub struct Overwriter<'a> { /* private fields */ }Expand description
A specialized engine for performing secure cryptographic overwrites on a file.
Implementations
Sourceimpl<'a> Overwriter<'a>
impl<'a> Overwriter<'a>
Sourcepub fn new(file: &'a mut File, verify: bool, cancelled: Arc<AtomicBool>) -> Self
pub fn new(file: &'a mut File, verify: bool, cancelled: Arc<AtomicBool>) -> Self
Creates a new Overwriter for a specific file handle.
Sourcepub fn execute(&mut self, method: ShredMethod, passes: u32) -> ShredResult<()>
pub fn execute(&mut self, method: ShredMethod, passes: u32) -> ShredResult<()>
Executes the full destruction sequence based on the selected method.